#! /usr/bin/perl
#
# Liquid Font Family
# Copyright (C) 2009 Henrik Theiling
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# SYNOPOSIS
# Tai Xuan Jing symbols can be created algorithmically
# very easily.  This is for the tetragrams in a 6x8
# or a 5x7 font (use -6x8 or -5x7).

my $width=  5;
my $height= 7;

sub glyph($$)
{
    my ($code, $glyph)= @_;
    printf ":0x%04x\n", $code;

    my $prefix= $width == 6 ? '.' : '';
    print "${prefix}.....\n" if $height == 8;
    for my $line (@$glyph) {
        print "${prefix}${line}\n";
    }
    print "\n";
}

######################################################################
# ARGV;

for my $arg (@ARGV) {
    if ($arg =~ /^-+([56])x([78])$/) {
        ($width, $height)= ($1,$2);
    }
    else {
        die "Error: Unrecognised option: $arg\n";
    }
}

######################################################################
# Main:
my @digit= (
    '#####',
    '##.##',
    '#.#.#',
);

# Tetragrams:
for my $a0 (0..2) {
    for my $a1 (0..2) {
        for my $a2 (0..2) {
            for my $a3 (0..2) {
                glyph (0x1d306 + $a3 + $a2*3 + $a1*9 + $a0*27,
                    [
                        $digit[$a0],
                        '.....',
                        $digit[$a1],
                        '.....',
                        $digit[$a2],
                        '.....',
                        $digit[$a3],
                    ]
                );
            }
        }
    }
}
